Crate bzr

Crate bzr 

Library crate for bzr — exposes modules for integration testing.

The primary entry point is the binary crate (main.rs). This library exists so that integration tests in tests/ can access internal modules.

Modules

cli
client
commands
config
credentials
Credential storage backends.
error
output
Output formatting modules.
types
url_parser
Parse Bugzilla buglist.cgi URLs into SavedQuery structs.
validation
Shared client-side input validators.
xmlrpc
XML-RPC transport adapter for Bugzilla servers that use the XML-RPC API instead of (or alongside) the REST API. Used internally by BugzillaClient when the detected ApiMode is XmlRpc or Hybrid.

Functions

dispatch
Dispatch a parsed CLI to the appropriate command handler.