Library crate for bzr — exposes modules for integration testing.
The primary entry point is the binary crate (main.rs). This library
exists so that integration tests in tests/ can access internal modules.
Modules
- cli
- client
- commands
- config
- credentials
- Credential storage backends.
- error
- types
- url_
parser - Parse Bugzilla
buglist.cgiURLs intoSavedQuerystructs. - xmlrpc
- XML-RPC transport adapter for Bugzilla servers that use the XML-RPC API
instead of (or alongside) the REST API. Used internally by
BugzillaClientwhen the detectedApiModeisXmlRpcorHybrid.
Functions
- dispatch
- Dispatch a parsed CLI to the appropriate command handler.